maze is a module for PLUMED2, which implements enhanced sampling methods for 
ligand unbinding from protein tunnels. The maze module is developed and 
maintained by [Jakub Rydzewski](http://www.fizyka.umk.pl/~jr) at the Institute 
of Physics, Nicolaus Copernicus University, Torun, Poland. See this 
[link](https://www.fizyka.umk.pl/~jr/maze.html) for additional information.

The maze module is an optional module for PLUMED2 that needs to be enabled when 
configuring the compilation of PLUMED2. You can either pass a flag
`--enable-modules=maze` or a `--enable-modules=all` when running the 
configure script. 
